@@ -30,6 +30,8 @@ where
     fn emit_class_decl(&mut self, node: &ClassDecl) -> Result {
         self.emit_leading_comments_of_span(node.span(), false)?;
 
+        srcmap!(node, true);
+
         if node.declare {
             keyword!("declare");
             space!();
@@ -50,6 +52,8 @@ where
     fn emit_fn_decl(&mut self, node: &FnDecl) -> Result {
         self.emit_leading_comments_of_span(node.span(), false)?;
 
+        srcmap!(node, true);
+
         if node.declare {
             keyword!("declare");
             space!();
@@ -77,15 +81,14 @@ where
     fn emit_var_decl(&mut self, node: &VarDecl) -> Result {
         self.emit_leading_comments_of_span(node.span, false)?;
 
+        srcmap!(node, true);
+
         if node.declare {
             keyword!("declare");
             space!();
         }
 
-        {
-            let span = self.cm.span_until_char(node.span, ' ');
-            keyword!(span, node.kind.as_str());
-        }
+        keyword!(node.kind.as_str());
 
         let starts_with_ident = match node.decls.first() {
             Some(VarDeclarator {
@@ -105,12 +108,16 @@ where
             Some(&node.decls),
             ListFormat::VariableDeclarationList,
         )?;
+
+        srcmap!(node, false);
     }
 
     #[emitter]
     fn emit_var_declarator(&mut self, node: &VarDeclarator) -> Result {
         self.emit_leading_comments_of_span(node.span(), false)?;
 
+        srcmap!(node, true);
+
         emit!(node.name);
 
         if let Some(ref init) = node.init {
@@ -119,6 +126,8 @@ where
             formatting_space!();
             emit!(init);
         }
+
+        srcmap!(node, false);
     }
 }
 
